# API Reference

Quick reference for the current public API.

For provider-level feature differences, see [Provider Capabilities](provider-capabilities.md).

## Entry Points

The primary execution functions are exported from `pollux`:

::: pollux.run

::: pollux.run_many

::: pollux.continue_tool

## Core Types

::: pollux.Source

::: pollux.Config

::: pollux.Options

::: pollux.RetryPolicy

::: pollux.ResultEnvelope

## Error Types

::: pollux.PolluxError

::: pollux.ConfigurationError

::: pollux.SourceError

::: pollux.PlanningError

::: pollux.InternalError

::: pollux.APIError

::: pollux.RateLimitError

::: pollux.CacheError
